@@ -34,11 +34,10 @@ class Game(gtk.DrawingArea):
         #self.connect("button-press-event", self.mus)
         #self.connect("key-press-event", self.key)
 
-        #try:
-
-        self.doc = SVG("res/" + region + ".svg")
-#        except:
- #           self.doc = SVG("/opt/leif/src/res/" + region + ".svg")
+        try:
+            self.doc = SVG("res/" + region + ".svg")
+        except:
+            self.doc = SVG("/opt/leif/src/res/" + region + ".svg")
 
         self.country_codes = self.doc.get_country_codes()
 
